pytomography.callbacks.callback — PyTomography 0.8.0 documentation

Skip to main content
`Ctrl`+`K`

# `pytomography.callbacks.callback`

## Module Contents

### Classes

`CallBack` | Abstract class used for callbacks. Subclasses must redefine the `__init__` and `run` methods. If a callback is used as an argument in an iterative reconstruction algorihtm, the `__run__` method is called after each subiteration.

class pytomography.callbacks.callback.CallBack

  Abstract class used for callbacks. Subclasses must redefine the `__init__` and `run` methods. If a callback is used as an argument in an iterative reconstruction algorihtm, the `__run__` method is called after each subiteration.

  abstract run(obj, n_iter, n_subset)

    Abstract method for `run`.

    Parameters:

      - obj (torch.tensor[batch_size, Lx, Ly, Lz]) – An object which one can compute various statistics from.

      - n_iter (int) – The iteration number

      - n_subset (int) – The subiteration number